@@ -31,7 +31,7 @@ class Account(ModelSQL, ModelView):
                 'required': "type != 'root'",
             })
     parent = fields.Many2One('analytic_account.account', 'Parent', select=2,
-            domain="[('parent', 'child_of', root)]",
+            domain=["('parent', 'child_of', root)"],
             states={
                 'invisible': "type == 'root'",
                 'required': "type != 'root'",
@@ -133,16 +133,22 @@ class Account(ModelSQL, ModelView):
         line_query = line_obj.query_get(cursor, user, context=context)
         cursor.execute('SELECT a.id, ' \
                     'SUM((COALESCE(l.debit, 0) - COALESCE(l.credit, 0))), ' \
-                    'l.currency ' \
+                    'c.currency ' \
                 'FROM analytic_account_account a ' \
                     'LEFT JOIN analytic_account_line l ' \
                     'ON (a.id = l.account) ' \
+                    'LEFT JOIN account_move_line ml ' \
+                    'ON (ml.id = l.move_line) ' \
+                    'LEFT JOIN account_account aa ' \
+                    'ON (aa.id = ml.account) ' \
+                    'LEFT JOIN company_company c ' \
+                    'ON (c.id = aa.company) ' \
                 'WHERE a.type != \'view\' ' \
                     'AND a.id IN (' + \
-                        ','.join(['%s' for x in all_ids]) + ') ' \
+                        ','.join(('%s',) * len(all_ids)) + ') ' \
                     'AND ' + line_query + ' ' \
                     'AND a.active ' \
-                'GROUP BY a.id, l.currency', all_ids)
+                'GROUP BY a.id, c.currency', all_ids)
         account_sum = {}
         id2currency = {}
         for account_id, sum, currency_id in cursor.fetchall():
@@ -196,16 +202,22 @@ class Account(ModelSQL, ModelView):
         line_query = line_obj.query_get(cursor, user, context=context)
         cursor.execute('SELECT a.id, ' \
                     'SUM(COALESCE(l.' + name + ', 0)), ' \
-                    'l.currency ' \
+                    'c.currency ' \
                 'FROM analytic_account_account a ' \
                     'LEFT JOIN analytic_account_line l ' \
                     'ON (a.id = l.account) ' \
+                    'LEFT JOIN account_move_line ml ' \
+                    'ON (ml.id = l.move_line) ' \
+                    'LEFT JOIN account_account aa ' \
+                    'ON (aa.id = ml.account) ' \
+                    'LEFT JOIN company_company c ' \
+                    'ON (c.id = aa.company) ' \
                 'WHERE a.type != \'view\' ' \
                     'AND a.id IN (' + \
-                        ','.join(['%s' for x in ids]) + ') ' \
+                        ','.join(('%s',) * len(ids)) + ') ' \
                     'AND ' + line_query + ' ' \
                     'AND a.active ' \
-                'GROUP BY a.id, l.currency', ids)
+                'GROUP BY a.id, c.currency', ids)
 
         id2currency = {}
         for account_id, sum, currency_id in cursor.fetchall():
